{
  description = "Gargantext PureScript fronetnd";

  inputs.flake-utils.url = "github:numtide/flake-utils";

  inputs.nixpkgs.url = "github:NixOS/nixpkgs";

  inputs.purescript-overlay = {
    url = "github:thomashoneyman/purescript-overlay";
    inputs.nixpkgs.follows = "nixpkgs";
  };
  
  outputs = { self, nixpkgs, flake-utils, purescript-overlay }:
    flake-utils.lib.eachDefaultSystem (system:
      #let pkgs = nixpkgs.legacyPackages.${system};
      let
        pkgs = import nixpkgs {
          inherit system;
          overlays = [ purescript-overlay.overlays.default ];
        };

        dependencies = with pkgs; [
          purescript
          #spago-unstable
          nodejs
          nodePackages.npm
        ];
    
      serve = pkgs.writeShellScriptBin "serve" ''
        set -e
    
        #yarn server
        npm run server
    
      '';
    
      build-watch = pkgs.writeShellScriptBin "build-watch" ''
        set -e
    
        echo "Build watch"
        npm spago build -w --then browserify
      '';
    
      build-zephyr = pkgs.writeShellScriptBin "build-zephyr" ''
        set -e
    
        npm spago build --purs-args '--codegen corefn,js'
        zephyr -f Main.main
        browserify-zephyr
      '';
    
      minify-bundle = pkgs.writeShellScriptBin "minify-bundle" ''
        set -e
    
        npm run minify
      '';
    
      in
        {
          packages = {
            compile = pkgs.writeShellApplication {
              name = "compile";
              runtimeInputs = dependencies;
              text = ''
              #!${pkgs.stdenv.shell}
              set -e

              echo "Installing JS Dependencies"
              #${pkgs.nodePackages.npm}/bin/npm install
              # https://docs.npmjs.com/cli/v9/commands/npm-ci
              ${pkgs.nodePackages.npm}/bin/npm ci
              #${pkgs.nodePackages.npm}/bin/npm install --dev
          
              echo "Compiling"
              ${pkgs.nodePackages.npm}/bin/npm run build
              '';
            };
            build = pkgs.writeShellApplication {
              name = "build";
              runtimeInputs = dependencies;
              text = ''
              #!${pkgs.stdenv.shell}
              set -e

              ${self.packages.${system}.compile}/bin/compile

              echo "Bundling"
              ${pkgs.nodePackages.npm}/bin/npm run bundle              
              '';
            };
            test-ps = pkgs.writeShellApplication {
              name = "test-ps";
              runtimeInputs = dependencies;
              text = ''
              #!${pkgs.stdenv.shell}
              set -e
          
              ${self.packages.${system}.compile}/bin/compile
          
              echo "Testing"
              ${pkgs.nodePackages.npm}/bin/npm run test
            '';
            };    
            repl = pkgs.writeShellApplication {
              name = "repl";
              runtimeInputs = dependencies;
              text = ''
              #!${pkgs.stdenv.shell}
          
              ${pkgs.nodePackages.npm}/bin/npm run repl
            '';
            };
            
            build-css = pkgs.writeShellApplication {
              name = "build-css";
              runtimeInputs = dependencies;
              text = ''
              #!${pkgs.stdenv.shell}
              set -e
          
              #yarn css
              ${pkgs.nodePackages.npm}/bin/npm run css
            '';
            };
          };
          
          devShells.default = pkgs.mkShell {
            name = "purescript-gargantext";
            #inputsFrom = builtins.attrValues self.packages.${system};
            buildInputs = with pkgs; (dependencies ++ [
              # scripts
              self.packages.${system}.build
              self.packages.${system}.compile
              self.packages.${system}.test-ps
              self.packages.${system}.repl
              
              self.packages.${system}.build-css
              build-watch
              build-zephyr
              minify-bundle
              serve
            ]);
          };
        }
    );
}
